@@ -60,6 +60,18 @@ class PlotAxis(AbstractOverlay):
 
     # The color of the tick labels.
     tick_label_color = ColorTrait("black")
+    
+    # The rotation of the tick labels.  (Only multiples of 90 are supported)
+    tick_label_rotate_angle = Float(0)
+    
+    # Whether to align to corners or edges (corner is better for 45 degree rotation)
+    tick_label_alignment = Enum('edge', 'corner')
+    
+    # The margin around the tick labels.
+    tick_label_margin = Int(2)
+    
+    # The distance of the tick label from the axis.
+    tick_label_offset = Float(8.)
 
     # A callable that is passed the numerical value of each tick label and
     # that returns a string.
@@ -352,8 +364,8 @@ class PlotAxis(AbstractOverlay):
 
         if self.title_spacing != 'auto':
             v_offset = self.title_spacing
-       	calculate_v_offset = (self.title_spacing) and (v_offset is None )
-        
+        calculate_v_offset = (self.title_spacing) and (v_offset is None )
+           
         if self.title_angle == 0:
             text_center_to_corner = -tl_bounds/2.0
             if calculate_v_offset:
@@ -361,6 +373,12 @@ class PlotAxis(AbstractOverlay):
                     v_offset = 25
                 else:
                     v_offset = max([l._bounding_box[1] for l in self.ticklabel_cache]) * 1.3
+                    
+            # The text_center_to_corner is used on the bottom as where the 
+            # top, left of the text should be. On the top of the plot, it 
+            # should not be used 
+            if self.orientation == 'top':
+                text_center_to_corner[1] = 0
                            
             offset = (self._origin_point+self._end_axis_point)/2
             center_dist = self._center_dist(-self._inside_vector, tl_bounds[0], tl_bounds[1], rotation=self.title_angle)
@@ -385,8 +403,8 @@ class PlotAxis(AbstractOverlay):
                 if not self.ticklabel_cache:
                     v_offset = 25
                 else:
-                    v_offset = (self._end_axis_point[1] - self._origin_point[1] + tl_bounds[0])/2.0
-            h_offset = self.tick_out + tl_bounds[1] + 8
+                    v_offset = (self._end_axis_point[1] - self._origin_point[1] - tl_bounds[0])/2.0
+            h_offset = self.tick_out + 4
             if len(self.ticklabel_cache) > 0:
                 h_offset += max([l._bounding_box[0] for l in self.ticklabel_cache]) 
             offset = array([self._origin_point[0] + h_offset, self._origin_point[1] + v_offset])
@@ -443,9 +461,17 @@ class PlotAxis(AbstractOverlay):
             #Note: This is not necessarily optimal for non
             #horizontal/vertical axes.  More work could be done on this.
 
-            base_position = (self._center_dist(-self._inside_vector, *tl_bounds)+8) \
-                                * -self._inside_vector \
-                                - tl_bounds/2.0 + self._tick_label_positions[i]
+            if self.tick_label_alignment == 'edge':
+                base_position = (self._center_dist(-self._inside_vector,
+                    rotation=0, *tl_bounds) + \
+                    self.tick_label_offset) * -self._inside_vector - \
+                    tl_bounds/2.0 + self._tick_label_positions[i]
+            else:
+                base_position = self._tick_label_positions[i] - \
+                    self._corner_dist(-self._inside_vector,
+                        ticklabel.get_bounding_poly(gc)[:-1]) - \
+                    self.tick_label_offset*self._inside_vector
+                    
 
             if self.ensure_labels_bounded:
                 pushdir = 0
@@ -565,7 +591,9 @@ class PlotAxis(AbstractOverlay):
                 tickstring = str(val)
             ticklabel = Label(text=tickstring,
                               font=self.tick_label_font,
-                              color=self.tick_label_color)
+                              color=self.tick_label_color,
+                              rotate_angle=self.tick_label_rotate_angle,
+                              margin=self.tick_label_margin)
             self.ticklabel_cache.append(ticklabel)
 
         # TODO: Right now we are hardcoding this handling of a scaled CTM,
@@ -656,7 +684,7 @@ class PlotAxis(AbstractOverlay):
             # fixme: this should take into account axis orientation
             screenhigh = self.x2
             screenlow = self.x
-
+            
         if self.orientation in ('top', 'bottom'):
             self._major_axis_size = self.bounds[0]
             self._minor_axis_size = self.bounds[1]
@@ -711,7 +739,8 @@ class PlotAxis(AbstractOverlay):
         the center of the rectangle, to wherever the vector leaves the
         rectangle. This method is useful for determining where to place text so
         it doesn't run into other components. """
-        rotvec = transpose(dot(self._rotmatrix(rotation*pi/180.0), transpose(array([vect], float64))))[0]
+        rotvec = transpose(dot(self._rotmatrix(rotation*pi/180.0),
+            transpose(array([vect], float64))))[0]
         absvec = absolute(rotvec)
         if absvec[1] != 0:
             heightdist = (float(height)/2)/float(absvec[1])
@@ -724,7 +753,13 @@ class PlotAxis(AbstractOverlay):
 
         return min(heightdist, widthdist)
 
-
+    def _corner_dist(self, vect, corners):
+        """Given a list of corner vectors, this method finds the
+        corner which is most extreme in the direction of the vector.
+        """
+        dots = array([dot(vect, corner) for corner in corners])
+        return corners[dots.argmin()]
+        
     #------------------------------------------------------------------------
     # Event handlers
     #------------------------------------------------------------------------
@@ -847,6 +882,15 @@ class PlotAxis(AbstractOverlay):
 
     def _tick_label_color_changed(self):
         return self._invalidate()
+    
+    def _tick_label_rotate_angle_changed(self):
+        return self._invalidate()
+    
+    def _tick_label_margin_changed(self):
+        return self._invalidate()
+    
+    def _tick_label_offset_changed(self):
+        return self._invalidate()
 
     def _tick_in_changed(self):
         return self._invalidate()
