@@ -3,7 +3,7 @@ CompositeIconRenderer classes.
 """
 from numpy import array, zeros_like
 
-from enthought.enable.api import white_color_trait
+from enthought.enable.api import black_color_trait, white_color_trait
 from enthought.kiva import font_metrics_provider
 from enthought.kiva.traits.kiva_font_trait import KivaFont
 from enthought.traits.api import Any, Dict, Enum, Bool, HasTraits, Int, \
@@ -75,6 +75,9 @@ class Legend(AbstractOverlay):
     # The border is visible (overrides Enable Component).
     border_visible = True
 
+    # The color of the text labels
+    color = black_color_trait
+
     # The background color of the legend (overrides AbstractOverlay).
     bgcolor = white_color_trait
 
@@ -202,13 +205,19 @@ class Legend(AbstractOverlay):
         else:
             x = component.x
         self.outer_position = [x, y]
+        
         if self.clip_to_component:
             c = self.component
             gc.save_state()
-            gc.clip_to_rect(c.x, c.y, c.width, c.height)
-        PlotComponent._draw(self, gc, view_bounds, mode)
-        if self.clip_to_component:
-            gc.restore_state()
+            try:
+                gc.clip_to_rect(c.x, c.y, c.width, c.height)
+                PlotComponent._draw(self, gc, view_bounds, mode)
+            finally:
+                gc.restore_state()
+        else:
+            PlotComponent._draw(self, gc, view_bounds, mode)
+            
+            
         return
 
     # The following two methods implement the functionality of the Legend
@@ -249,7 +258,8 @@ class Legend(AbstractOverlay):
 
         gc.save_state()
         try:
-            gc.clip_to_rect(self.x, self.y, self.width, self.height)
+            gc.clip_to_rect(int(self.x), int(self.y), 
+                            int(self.width), int(self.height))
             edge_space = self.border_width + self.border_padding
             icon_width, icon_height = self.icon_bounds
 
@@ -446,8 +456,8 @@ class Legend(AbstractOverlay):
         """ Returns a new Label instance for the given text.  Subclasses can
         override this method to customize the creation of labels.
         """
-        return Label(text=text, font=self.font, margin=0, bgcolor="transparent",
-                     border_width=0)
+        return Label(text=text, font=self.font, margin=0, color=self.color_,
+                     bgcolor="transparent", border_width=0)
 
     def _composite_icon_renderer_default(self):
         return CompositeIconRenderer()
@@ -460,6 +470,8 @@ class Legend(AbstractOverlay):
                     "position", "position_items", "bounds", "bounds_items",
                     "label_at_top"):
             self._layout_needed = True
+        if name == "color":
+            self.get_preferred_size()
         return
 
 
