@@ -374,20 +374,28 @@ def strftimeEx(fmt, t, timetuple=None):
     Expects input to be a floating-point number of seconds since epoch.
     The formats are:
         
-    - ``%(ms)``:  milliseconds
-    - ``%(us)``:  microseconds
+    - ``%(ms)``:  milliseconds (uses round())
+    - ``%(ms_)``: milliseconds (uses floor())
+    - ``%(us)``:  microseconds (uses round())
     """
 
     if "%(ms)" in fmt:
-        ms = round(fmod(t, 1) * 1000)
+        # Assume that fmt does not also contain %(ms_) and %(us).
+        # (It really doesn't make sense to mix %(ms) with those.)
+        secs, frac = divmod(round(t,3), 1)
+        ms = int(round(1e3*frac))
         fmt = fmt.replace("%(ms)", "%03d" % ms)
-
-    if "%(us)" in fmt:
-        us = round(fmod(t, 1e-3) * 1000000)
+    else:
+        # Assume fmt contains %(ms_) and %(us).
+        secs, frac = divmod(round(t,6), 1)
+        ms = int(round(1e3*frac))
+        ms_, us = divmod(int(round(1e6*frac)),1000)
+        fmt = fmt.replace("%(ms_)", "%03d" % ms_)
         fmt = fmt.replace("%(us)", "%03d" % us)
 
     if not timetuple:
-        timetuple = localtime(t)
+        timetuple = localtime(secs)
+
     return strftime(fmt, timetuple)
     
 
@@ -395,9 +403,9 @@ class TimeFormatter(object):
     """ Formatter for time values.
     """
     # This table of format is convert into the 'formats' dict.  Each tuple of
-    # formats must be ordered from shortest to longest.  Use %T for milliseconds.
+    # formats must be ordered from shortest to longest.
     _formats = {
-        'microseconds': ('%(us)us', '%(ms).%(us)'),
+        'microseconds': ('%(us)us', '%(ms_).%(us)ms'),
         'milliseconds': ('%(ms)ms', '%S.%(ms)s'),
         'seconds': (':%S', '%Ss'),
         'minsec': ('%M:%S',), # '%Mm%S', '%Mm%Ss'),
@@ -560,10 +568,14 @@ class TimeFormatter(object):
                 s = strftimeEx(next_format, t, tm)
 
             if self.strip_leading_zeros:
-                labels.append(s.lstrip("0"))
+                ss = s.lstrip('0')
+                if ss != s and (ss == '' or not ss[0].isdigit()):
+                    # A label such as '000ms' should leave one zero.
+                    ss = '0' + ss
+                labels.append(ss)
             else:
                 labels.append(s)
-            
+
         return labels
 
     def estimate_width(self, start, end, numlabels=None, char_width=None,
