@@ -170,6 +170,14 @@ class PlotAxis(AbstractOverlay):
         self.invalidate_draw()
         return
 
+    def traits_view(self):
+        """ Returns a View instance for use with Traits UI.  This method is
+        called automatically be the Traits framework when .edit_traits() is
+        invoked.
+        """
+        from axis_view import AxisView
+        return AxisView
+
     #------------------------------------------------------------------------
     # PlotComponent and AbstractOverlay interface
     #------------------------------------------------------------------------
