@@ -1,6 +1,10 @@
 """ Defines commands for the Chaco shell.
 """
-import wx
+
+try:
+    from wx import GetApp
+except ImportError:
+    GetApp = lambda: None
 
 from enthought.chaco.api import Plot, color_map_name_dict
 from enthought.chaco.scales.api import ScaleSystem
@@ -179,7 +183,10 @@ def show():
     prompt.
     """
 
-    app = wx.GetApp()
+    app = GetApp()
+    if not app:
+        return
+
     if not(app.IsMainLoopRunning()):
         frame = session.active_window
         app.SetTopWindow(frame)
@@ -311,7 +318,7 @@ def semilogx(*data, **kwargs):
 
     Example::
         
-        x = linspace(0, 10.0 100)
+        x = linspace(0.01, 10.0 100)
         semilogx(x, sqrt(x), "b-")
 
     To use previous data, specify names instead of actual data arrays.
@@ -349,7 +356,7 @@ def loglog(*data, **kwargs):
 
     Example::
         
-        x = linspace(0, 10.0, 100)
+        x = linspace(0.001, 10.0, 100)
         loglog(x, x**2, "b-")
 
     To use previous data, specify names instead of actual data arrays.
@@ -695,6 +702,22 @@ def yscale(system=None):
     """
     _set_scale('y', system)
 
+def legend(setting=None):
+    """ Sets or toggles the presence of the legend
+
+    Usage
+    -----
+    * ``legend()``: toggles the legend; if it is currently visible, it is hideen, and if it is currently hidden, then it is displayed
+    * ``legend(True)``: shows the legend
+    * ``legend(False)``: hides the legend
+    """
+    p = curplot()
+    if p:
+        if setting is None:
+            setting = not p.legend.visible
+        p.legend.visible = setting
+        p.request_redraw()
+
 
 #-----------------------------------------------------------------------------
 # Tools
