@@ -1,25 +1,30 @@
+from better_zoom import BetterZoom
+from better_selecting_zoom import BetterSelectingZoom
 from broadcaster import BroadcasterTool
 from dataprinter import DataPrinter
 from data_label_tool import DataLabelTool
 from drag_zoom import DragZoom
-from drag_tool import DragTool
+from enthought.enable.tools.drag_tool import DragTool
 from draw_points_tool import DrawPointsTool
 from highlight_tool import HighlightTool
 from image_inspector_tool import ImageInspectorTool, ImageInspectorOverlay
 from lasso_selection import LassoSelection
 from legend_tool import LegendTool
+from legend_highlighter import LegendHighlighter
 from line_inspector import LineInspector
 from line_segment_tool import LineSegmentTool
 from move_tool import MoveTool
 from pan_tool import PanTool
 from point_marker import PointMarker
 from range_selection import RangeSelection
+from range_selection_2d import RangeSelection2D
 from range_selection_overlay import RangeSelectionOverlay
 from rect_zoom import RectZoomTool
 from regression_lasso import RegressionLasso, RegressionOverlay
 from save_tool import SaveTool
 from scatter_inspector import ScatterInspector
 from select_tool import SelectTool
+from simple_inspector import SimpleInspectorTool
 from simple_zoom import SimpleZoom
 from tracking_pan_tool import TrackingPanTool
 from tracking_zoom import TrackingZoom
