@@ -25,8 +25,9 @@ class RangeSelection(AbstractController):
     # and fires change-events as the user is dragging.
     selection = Property
     
-    # This event is fired when the user completes the selection.  The value of
-    # the event is the data space range
+    # This event is fired whenever the user completes the selection, or when a
+    # finalized selection gets modified.  The value of the event is the data
+    # space range.
     selection_completed = Event
 
     # The possible event states of this selection tool (overrides 
@@ -85,6 +86,9 @@ class RangeSelection(AbstractController):
     # Allow the left button begin a selection?
     left_button_selects = Bool(False)
     
+    # Allow the tool to be put into the deselected state via mouse clicks
+    allow_deselection = Bool(True)
+    
     #------------------------------------------------------------------------
     # Private traits
     #------------------------------------------------------------------------
@@ -136,10 +140,12 @@ class RangeSelection(AbstractController):
         deselection as an optional argument.
         """
         self.selection = None
+        self.selection_completed = None
         self.event_state = "normal"
         self.component.request_redraw()
         if event:
             event.window.set_pointer("arrow")
+            event.handled = True
         return
     
     #------------------------------------------------------------------------
@@ -179,8 +185,13 @@ class RangeSelection(AbstractController):
             self._down_point = array([event.x, event.y])
             self._down_data_coord = self.mapper.map_data(self._down_point)[self.axis_index]
             self._original_selection = array(self.selection)
-        else:
+        elif self.allow_deselection:
             self.deselect(event)
+        else:
+            # Treat this as a combination deselect + left down
+            self.deselect(event)
+            self.normal_left_down(event)
+        event.handled = True
         return
 
     def selected_right_down(self, event):
@@ -213,12 +224,17 @@ class RangeSelection(AbstractController):
                     self.event_state = "selecting"
                     self._drag_edge = "low"
                     self.selecting_mouse_move(event)
-                else:
+                elif self.allow_deselection:
                     self.deselect(event)
+                else:
+                    # Treat this as a combination deselect + right down
+                    self.deselect(event)
+                    self.normal_right_down(event)
         else:
             # Treat this as a combination deselect + right down
             self.deselect(event)
             self.normal_right_down(event)
+        event.handled = True
         return
     
     def selected_mouse_move(self, event):
@@ -243,6 +259,7 @@ class RangeSelection(AbstractController):
                     self._set_sizing_cursor(event)
                     return
         event.window.set_pointer("arrow")
+        event.handled = True
         return
     
     def selected_mouse_leave(self, event):
@@ -265,6 +282,8 @@ class RangeSelection(AbstractController):
         Switches the tool to the 'selected' state.
         """
         self.event_state = "selected"
+        self.selection_completed = self.selection
+        event.handled = True
         return
     
     def moving_mouse_move(self, event):
@@ -288,7 +307,9 @@ class RangeSelection(AbstractController):
             new_selection = (range.high - selection_data_width, range.high)
             
         self.selection = new_selection
+        self.selection_completed = new_selection
         self.component.request_redraw()
+        event.handled = True
         return
 
     def moving_mouse_leave(self, event):
@@ -385,6 +406,7 @@ class RangeSelection(AbstractController):
                         self._drag_edge = "high"
 
                 self.component.request_redraw()
+            event.handled = True
         return
 
     def selecting_button_up(self, event):
@@ -392,6 +414,7 @@ class RangeSelection(AbstractController):
 
         # Fire the "completed" event
         self.selection_completed = self.selection
+        event.handled = True
         return
 
     def selecting_right_up(self, event):
