@@ -4,12 +4,8 @@ This plot displays the audio spectrum from the microphone.
 
 Based on updating_plot.py
 """
-# Standard library imports
-import sys
-
 # Major library imports
 import pyaudio
-import wx
 from numpy import zeros, linspace, short, fromstring, hstack, transpose
 from scipy import fft
 
@@ -34,7 +30,7 @@ SPECTROGRAM_LENGTH = 100
 
 def _create_plot_component(obj):
     # Setup the spectrum plot
-    frequencies = linspace(0., float(SAMPLING_RATE)/2, num=NUM_SAMPLES/2)
+    frequencies = linspace(0.0, float(SAMPLING_RATE)/2, num=NUM_SAMPLES/2)
     obj.spectrum_data = ArrayPlotData(frequency=frequencies)
     empty_amplitude = zeros(NUM_SAMPLES/2)
     obj.spectrum_data.set_data('amplitude', empty_amplitude)
@@ -51,7 +47,7 @@ def _create_plot_component(obj):
     obj.spectrum_plot.value_axis.title = 'Amplitude'
 
     # Time Series plot
-    times = linspace(0., float(NUM_SAMPLES)/SAMPLING_RATE, num=NUM_SAMPLES)
+    times = linspace(0.0, float(NUM_SAMPLES)/SAMPLING_RATE, num=NUM_SAMPLES)
     obj.time_data = ArrayPlotData(time=times)
     empty_amplitude = zeros(NUM_SAMPLES)
     obj.time_data.set_data('amplitude', empty_amplitude)
@@ -71,14 +67,12 @@ def _create_plot_component(obj):
     obj.spectrogram_plotdata = ArrayPlotData()
     obj.spectrogram_plotdata.set_data('imagedata', spectrogram_data)
     spectrogram_plot = Plot(obj.spectrogram_plotdata)
-    spectrogram_time = linspace(
-        0.0, float(SPECTROGRAM_LENGTH*NUM_SAMPLES)/float(SAMPLING_RATE),
-        num=SPECTROGRAM_LENGTH)
-    spectrogram_freq = linspace(0.0, float(SAMPLING_RATE/2), num=NUM_SAMPLES/2)
+    max_time = float(SPECTROGRAM_LENGTH * NUM_SAMPLES) / SAMPLING_RATE
+    max_freq = float(SAMPLING_RATE / 2)
     spectrogram_plot.img_plot('imagedata',
                               name='Spectrogram',
-                              xbounds=spectrogram_time,
-                              ybounds=spectrogram_freq,
+                              xbounds=(0, max_time),
+                              ybounds=(0, max_freq),
                               colormap=jet,
                               )
     range_obj = spectrogram_plot.plots['Spectrogram'][0].value_mapper.range
@@ -94,19 +88,13 @@ def _create_plot_component(obj):
 
     return container
 
-
 _stream = None
 def get_audio_data():
     global _stream
     if _stream is None:
-        # The audio stream is opened the first time this function gets called.
-        # The stream is always closed (if it was opened) in a try finally
-        # block at the end of this file,
         pa = pyaudio.PyAudio()
-        _stream = pa.open(format=pyaudio.paInt16, channels=1,
-                          rate=SAMPLING_RATE,
-                          input=True, frames_per_buffer=NUM_SAMPLES)
-
+        _stream = pa.open(format=pyaudio.paInt16, channels=1, rate=SAMPLING_RATE,
+                     input=True, frames_per_buffer=NUM_SAMPLES)
     audio_data  = fromstring(_stream.read(NUM_SAMPLES), dtype=short)
     normalized_data = audio_data / 32768.0
     return (abs(fft(normalized_data))[:NUM_SAMPLES/2], normalized_data)
@@ -186,37 +174,62 @@ popup = Demo()
 # Stand-alone frame to display the plot.
 #============================================================================
 
-class PlotFrame(DemoFrame):
+from enthought.etsconfig.api import ETSConfig
 
-    def _create_window(self):
+if ETSConfig.enable_toolkit == "wx":
 
-        self.controller = TimerController()
-        container = _create_plot_component(self.controller)
-        # Bind the exit event to the onClose function which will force the
-        # example to close. The PyAudio package causes problems that normally
-        # prevent the user from closing the example using the 'X' button.
-        # NOTE: I believe it is sufficient to just stop the timer-Vibha.
-        self.Bind(wx.EVT_CLOSE, self.onClose)
+    import wx
+    class PlotFrame(DemoFrame):
 
-        # Set the timer to generate events to us
-        timerId = wx.NewId()
-        self.timer = wx.Timer(self, timerId)
-        self.Bind(wx.EVT_TIMER, self.controller.onTimer, id=timerId)
-        self.timer.Start(20.0, wx.TIMER_CONTINUOUS)
+        def _create_window(self):
 
-        # Return a window containing our plots
-        return Window(self, -1, component=container)
+            self.controller = TimerController()
+            container = _create_plot_component(self.controller)
+            # Bind the exit event to the onClose function which will force the
+            # example to close. The PyAudio package causes problems that normally
+            # prevent the user from closing the example using the 'X' button.
+            # NOTE: I believe it is sufficient to just stop the timer-Vibha.
+            self.Bind(wx.EVT_CLOSE, self.onClose)
 
-    def onClose(self, event):
-        #sys.exit()
-        self.timer.Stop()
-        event.Skip()
+            # Set the timer to generate events to us
+            timerId = wx.NewId()
+            self.timer = wx.Timer(self, timerId)
+            self.Bind(wx.EVT_TIMER, self.controller.onTimer, id=timerId)
+            self.timer.Start(20.0, wx.TIMER_CONTINUOUS)
 
+            # Return a window containing our plots
+            return Window(self, -1, component=container)
+
+        def onClose(self, event):
+            #sys.exit()
+            self.timer.Stop()
+            event.Skip()
+
+elif ETSConfig.enable_toolkit == "qt4":
+
+    from PyQt4 import QtGui, QtCore
+
+    class PlotFrame(DemoFrame):
+        def _create_window(self):
+            self.controller = TimerController()
+            container = _create_plot_component(self.controller)
+
+            # start a continuous timer
+            self.timer = QtCore.QTimer()
+            self.timer.timeout.connect(self.controller.onTimer)
+            self.timer.start(20)
+
+            return Window(self, -1, component=container)
+
+        def closeEvent(self, event):
+            # stop the timer
+            if getattr(self, "timer", None):
+                self.timer.stop()
+            return super(PlotFrame, self).closeEvent(event)
 
 if __name__ == "__main__":
     try:
         demo_main(PlotFrame, size=size, title=title)
     finally:
-        # Always close the audio stream
         if _stream is not None:
             _stream.close()
